Enum actix_web::error::DispatchError
source · [−]#[non_exhaustive]
pub enum DispatchError {
Service(Response<BoxBody>),
Body(Box<dyn Error + 'static, Global>),
Upgrade,
Io(Error),
Parse(ParseError),
H2(Error),
SlowRequestTimeout,
DisconnectTimeout,
HandlerDroppedPayload,
InternalError,
}Expand description
A set of errors that can occur during dispatching HTTP requests.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Service(Response<BoxBody>)
Service error.
Body(Box<dyn Error + 'static, Global>)
Body streaming error.
Upgrade
Upgrade service error.
Io(Error)
An io::Error that occurred while trying to read or write to a network stream.
Parse(ParseError)
Request parse error.
H2(Error)
HTTP/2 error.
SlowRequestTimeout
The first request did not complete within the specified timeout.
DisconnectTimeout
Disconnect timeout. Makes sense for ssl streams.
HandlerDroppedPayload
Handler dropped payload before reading EOF.
InternalError
Internal error.